@@ -4,7 +4,7 @@ from cubicweb.web.views.basecontrollers import JSonController
 
 @monkeypatch(JSonController)
 def js_update_edition_status(self, vfrql, usereid, will_edit):
-    vf = self.req.execute(vfrql).get_entity(0, 0)
+    vf = self._cw.execute(vfrql).get_entity(0, 0)
     if will_edit:
         vf.mark_downloaded_for_edition_by(usereid)
     else:
